(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     47527,        964]
NotebookOptionsPosition[     44557,        914]
NotebookOutlinePosition[     45132,        935]
CellTagsIndexPosition[     45089,        932]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 21 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}, {3.891080224224403*^9, 
   3.891080224709962*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"23bb004a-cbec-4894-b6f4-79dfe3294b96"],

Cell["Chapter 10, Section 10.7, Figure 10.25", "Section",ExpressionUUID->"3954cc47-6696-4078-8182-a1c29c90f4bd"],

Cell["\<\
Here we generate a plot showing the orbits of the F ring and its two \
shepherding satellites, Prometheus and Pandora at the same epoch.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.890482714803637*^9, 3.8904828537225943`*^9}, {
  3.890484151974325*^9, 3.8904841981973963`*^9}, {3.8904844623317413`*^9, 
  3.890484509340036*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"dd20e2c4-958f-4931-aaad-2f922072e35b"],

Cell["\<\
Give the Julian dates of each epoch and display them in date form.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.890482714803637*^9, 3.8904828537225943`*^9}, {
  3.890484151974325*^9, 3.8904841981973963`*^9}, {3.890484258189159*^9, 
  3.890484281525279*^9}, {3.890550934832878*^9, 3.8905509410818253`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f8a5ece4-cb8a-4b1e-bec9-25012ff9a2b4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rajepoch", "=", "2453005.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"njcepoch", "=", "2451545.0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.890484216677785*^9, 3.890484232501897*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"05afe8f3-5d15-4e65-9ce4-17a821c0fbc7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FromJulianDate", "[", "rajepoch", "]"}]], "Input",
 CellChangeTimes->{{3.890550883067252*^9, 3.8905508992575274`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"864c3523-6e9c-4139-a1aa-85858c5d08ea"],

Cell[BoxData[
 TemplateBox[{
   RowBox[{"\"Thu 1 Jan 2004 01:00:00\"", 
     StyleBox[
      RowBox[{"\"GMT\"", "\[InvisibleSpace]", "+", "\[InvisibleSpace]", 
        StyleBox["1", NumberMarks -> False, StripOnInput -> False]}], 
      FontColor -> GrayLevel[0.5]]}], 
   RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2004", ",", "1", ",", "1", ",", "1", ",", "0", ",", "0.`"}],
          "}"}], ",", "\"Instant\"", ",", "\"Gregorian\"", ",", "1.`"}], 
     "]"}]},
  "DateObject",
  Editable->False]], "Output",
 CellChangeTimes->{3.890550900353952*^9, 3.890551210741795*^9, 
  3.890556453789123*^9, 3.8905565553666286`*^9, 3.891103399824854*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"b6217b77-0d2f-4925-b3f1-7527ec2fe562"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FromJulianDate", "[", "njcepoch", "]"}]], "Input",
 CellChangeTimes->{{3.890550883067252*^9, 3.890550910449194*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"d24c1078-48c1-4eb0-a77f-5c75ac2cd852"],

Cell[BoxData[
 TemplateBox[{
   RowBox[{"\"Sat 1 Jan 2000 13:00:00\"", 
     StyleBox[
      RowBox[{"\"GMT\"", "\[InvisibleSpace]", "+", "\[InvisibleSpace]", 
        StyleBox["1", NumberMarks -> False, StripOnInput -> False]}], 
      FontColor -> GrayLevel[0.5]]}], 
   RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{
          "2000", ",", "1", ",", "1", ",", "13", ",", "0", ",", "0.`"}], 
         "}"}], ",", "\"Instant\"", ",", "\"Gregorian\"", ",", "1.`"}], "]"}]},
  "DateObject",
  Editable->False]], "Output",
 CellChangeTimes->{3.8905509115815067`*^9, 3.890551210749625*^9, 
  3.890556453800282*^9, 3.8905565553781*^9, 3.891103399834934*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"ae0743cd-3a4a-4ea1-a2ab-c358fcdc8cb9"]
}, Open  ]],

Cell["\<\
Give the orbital elements and relevant rates of change for Prometheus and \
Pandora from Jacobson et al. (2008).\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.890482714803637*^9, 3.8904828537225943`*^9}, {
  3.890484151974325*^9, 3.8904841981973963`*^9}, {3.890484258189159*^9, 
  3.890484319773038*^9}, {3.890484353052822*^9, 3.890484363236071*^9}, {
  3.89048440847622*^9, 3.890484415308014*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"37a11101-4ad2-4b4e-b133-8299aa28124c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"aprom", "=", "139380"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eprom", "=", "0.0022"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cpprom0", "=", "63.8218"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cppromdot", "=", "2.7577"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"apand", "=", "141710"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"epand", "=", "0.0042"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cppand0", "=", "50.6769"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cppanddot", "=", "2.5996"}], ";"}]}], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"f29d89dc-9792-4350-a598-94d873abf3c7"],

Cell["\<\
Give the orbital elements  and relevant rates of change for the F ring core \
from Cooper et al. (2013).\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.890482714803637*^9, 3.8904828537225943`*^9}, {
   3.890484151974325*^9, 3.8904841981973963`*^9}, {3.890484258189159*^9, 
   3.890484319773038*^9}, {3.890484353052822*^9, 3.890484388723938*^9}, 
   3.89048442359814*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"786090b6-295b-4f50-a205-983c3f6ddbf9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"afring", "=", "140223.92"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"efring", "=", 
   RowBox[{"2.3636", "*", 
    RowBox[{"10", "^", 
     RowBox[{"(", 
      RowBox[{"-", "3"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cpfring0", "=", "8.8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cpfringdot", "=", "2.7052"}], ";"}]}], "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"83f8ae4a-264a-43af-8aeb-15f111cc5e1d"],

Cell[TextData[{
 "Define a function ",
 StyleBox["cpcalc", "Input"],
 " to calculate the longitude of periapse at a given date using its value at \
a particular epoch and its rate of change."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.890482714803637*^9, 3.8904828537225943`*^9}, {
   3.890484151974325*^9, 3.8904841981973963`*^9}, {3.890484258189159*^9, 
   3.890484319773038*^9}, {3.890484353052822*^9, 3.890484388723938*^9}, 
   3.89048442359814*^9, {3.890484595083332*^9, 3.8904846652348213`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8da042bb-6b88-4793-9ea7-446c51ef1dd3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cpcalc", "[", 
   RowBox[{"cp0_", ",", "cpdot_", ",", "epoch_", ",", "date_"}], "]"}], ":=", 
  
  RowBox[{"Mod", "[", 
   RowBox[{
    RowBox[{"cp0", "+", 
     RowBox[{"cpdot", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"JulianDate", "[", "date", "]"}], "-", "epoch"}], ")"}]}]}], 
    ",", "360"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.89048468693891*^9, 3.890484688922056*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"5060e3ae-eb66-4e4b-bcc1-d8463b969427"],

Cell[TextData[{
 "Define a function ",
 StyleBox["orbplot", "Input"],
 " to plot radius as a function of longitude for given semi-major axis, \
eccentricity and longitude of periapse."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.890482714803637*^9, 3.8904828537225943`*^9}, {
   3.890484151974325*^9, 3.8904841981973963`*^9}, {3.890484258189159*^9, 
   3.890484319773038*^9}, {3.890484353052822*^9, 3.890484388723938*^9}, 
   3.89048442359814*^9, {3.890484595083332*^9, 3.8904846652348213`*^9}, {
   3.890484762177761*^9, 3.89048476420352*^9}, {3.8904848411054077`*^9, 
   3.890484894048552*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3e74cc54-6392-47e7-b818-5d4430838802"],

Cell[BoxData[
 RowBox[{
  RowBox[{"orbplot", "[", 
   RowBox[{"a_", ",", "e_", ",", "\[Omega]_", ",", "color_"}], "]"}], ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"e", "^", "2"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"e", "*", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Theta]", "-", "\[Omega]"}], ")"}], "Degree"}], 
          "]"}]}]}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Theta]", ",", "0", ",", "360"}], "}"}], ",", 
    RowBox[{"FrameTicks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"139000", ",", "140000", ",", "141000", ",", "142000"}], 
          "}"}], ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "90", ",", "180", ",", "270", ",", "360"}], "}"}],
          ",", "None"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "->", "color"}], ",", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8904847766435347`*^9, 3.890484808097484*^9}, 
   3.890485382503655*^9, 3.890485700454941*^9, 3.8904982804818163`*^9, 
   3.890498348904484*^9, {3.890498940147533*^9, 3.890498944771755*^9}, 
   3.8905475158182383`*^9, {3.890547643584395*^9, 3.890547647047616*^9}, {
   3.890547696983735*^9, 3.8905477151671*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"a8b6bf6b-95ec-4b7e-be10-934a4f04bf35"],

Cell["Set the colours for the orbits of Prometheus and Pandora.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8706886125517807`*^9, 3.8706886208470783`*^9}, {
   3.879326645518285*^9, 3.879326704748672*^9}, {3.879335103599725*^9, 
   3.879335199480815*^9}, {3.881407307594336*^9, 3.881407326537808*^9}, {
   3.8905554141644993`*^9, 3.8905554355881157`*^9}, 3.890555471395228*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"57f9736f-4ca3-4ae4-a702-9f8509486bef"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"color2", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8706884723044577`*^9, 3.8706884767572603`*^9}, {
  3.890485224222741*^9, 3.890485225329157*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"1ae8a2c8-6210-4ba7-afe2-e0ed557c9bd4"],

Cell["Set the labels for Prometheus, Pandora and the F ring.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8706886125517807`*^9, 3.8706886208470783`*^9}, {
  3.879326645518285*^9, 3.879326704748672*^9}, {3.879335103599725*^9, 
  3.879335199480815*^9}, {3.881407307594336*^9, 3.881407326537808*^9}, {
  3.89055540378874*^9, 3.8905554050522823`*^9}, {3.890555487876232*^9, 
  3.890555498474471*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"dff6ebb5-383b-4adf-afda-b84f23db2a90"],

Cell[BoxData[
 RowBox[{
  RowBox[{"prompanfr", "=", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Prometheus\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"270.4", ",", "138800"}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<F ring\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"43.4", ",", "140500"}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Pandora\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"89.9", ",", "142000"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8905555047723007`*^9, 3.8905555441483717`*^9}, {
  3.890555651164118*^9, 3.890555832536339*^9}, {3.890555884389599*^9, 
  3.890555960186318*^9}, {3.890555994177883*^9, 3.890556134777998*^9}, {
  3.890556394289241*^9, 3.890556423243539*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"de7daba8-d569-4228-8e06-97d82d5a0442"],

Cell[TextData[{
 "Now define a function ",
 StyleBox["orbplot3", "Input"],
 " to plot radius as a function of longitude for a given date, semi-major \
axis, eccentricity and longitude of periapse for three sets of orbital \
elements."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.890482714803637*^9, 3.8904828537225943`*^9}, {
   3.890484151974325*^9, 3.8904841981973963`*^9}, {3.890484258189159*^9, 
   3.890484319773038*^9}, {3.890484353052822*^9, 3.890484388723938*^9}, 
   3.89048442359814*^9, {3.890484595083332*^9, 3.8904846652348213`*^9}, {
   3.890484762177761*^9, 3.89048476420352*^9}, {3.8904848411054077`*^9, 
   3.890484894048552*^9}, {3.8904849361444197`*^9, 3.890484963447556*^9}, {
   3.890548672127962*^9, 3.8905486777356653`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"06a75a5d-185b-4ec8-86cc-f78b7e5ae589"],

Cell[BoxData[
 RowBox[{
  RowBox[{"orbplot3", "[", "date_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"p1", "=", 
      RowBox[{"orbplot", "[", 
       RowBox[{"aprom", ",", "eprom", ",", 
        RowBox[{"cpcalc", "[", 
         RowBox[{"cpprom0", ",", "cppromdot", ",", "rajepoch", ",", "date"}], 
         "]"}], ",", "color1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"p2", "=", 
      RowBox[{"orbplot", "[", 
       RowBox[{"apand", ",", "epand", ",", 
        RowBox[{"cpcalc", "[", 
         RowBox[{"cppand0", ",", "cppanddot", ",", "rajepoch", ",", "date"}], 
         "]"}], ",", "color2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"p3", "=", 
      RowBox[{"orbplot", "[", 
       RowBox[{"afring", ",", "efring", ",", 
        RowBox[{"cpcalc", "[", 
         RowBox[{
         "cpfring0", ",", "cpfringdot", ",", "njcepoch", ",", "date"}], "]"}],
         ",", "Green"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p1", ",", "p2", ",", "p3", ",", "prompanfr"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "360"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"138500", ",", "142500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameTicks", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"139000", ",", "140000", ",", "141000", ",", "142000"}], 
             "}"}], ",", "None"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "90", ",", "180", ",", "270", ",", "360"}], 
             "}"}], ",", "None"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "138500"}], "}"}]}], ",", 
       RowBox[{"FrameStyle", "\[Rule]", 
        RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<True Longitude (deg.)\>\"", ",", 
          "\"\<Orbital Radius (km)\>\""}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.890484976257187*^9, 3.890484977440619*^9}, {
   3.890485550341897*^9, 3.8904856808459463`*^9}, {3.890485759292492*^9, 
   3.890485846827828*^9}, {3.890498199753956*^9, 3.89049825379681*^9}, {
   3.890498307153429*^9, 3.890498320791134*^9}, 3.890498977030706*^9, {
   3.890547468003126*^9, 3.89054749781924*^9}, {3.890547591350075*^9, 
   3.890547616964752*^9}, {3.8905476692647343`*^9, 3.8905476857515907`*^9}, {
   3.890547733861331*^9, 3.89054776068116*^9}, {3.890548824711184*^9, 
   3.8905488308947477`*^9}, {3.890555856968635*^9, 3.890555860456423*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"b1b01bc4-ec06-499d-ab8c-fea4d077048b"],

Cell["\<\
Display the three orbits on 1st July 2004.  This is a revised version of \
Fig.10.25.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.890482714803637*^9, 3.8904828537225943`*^9}, {
   3.890484151974325*^9, 3.8904841981973963`*^9}, {3.890484258189159*^9, 
   3.890484319773038*^9}, {3.890484353052822*^9, 3.890484388723938*^9}, 
   3.89048442359814*^9, {3.890484595083332*^9, 3.8904846652348213`*^9}, {
   3.890484762177761*^9, 3.89048476420352*^9}, {3.8904848411054077`*^9, 
   3.890484894048552*^9}, {3.8904849361444197`*^9, 3.890484963447556*^9}, {
   3.890548672127962*^9, 3.8905486777356653`*^9}, {3.8905510092398653`*^9, 
   3.890551027015308*^9}, {3.890551166620964*^9, 3.89055118082096*^9}, {
   3.890556479354556*^9, 3.890556493665263*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f742d7b3-aa23-4027-a625-268211c3b35f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"orbplot3", "[", 
  RowBox[{"{", 
   RowBox[{"2004", ",", "7", ",", "1"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.890548557978153*^9, 3.890548566489595*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"3be279e8-b700-475f-9f43-87958befc139"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwd2Xk4lF0UAHBkyZY1e7LFJ0L23Rlb9iyVNcQYM2PfhhQqiZBUtClLISlE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        "]]},
      Annotation[#, "Charting`Private`Tag$3377#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwd2Xk4VO0bB3ATrSglIYpCWQrZosQ9CBUiLdYwcwZjNzNnkqSNtFlbLKVE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        "]]},
      Annotation[#, "Charting`Private`Tag$3555#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwd2Xk8VF8UAHBLJKSIrK12FWWJSpwJKXu0YCwzQyHCzBuThH4qKpWQLdkq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        "]]},
      Annotation[#, "Charting`Private`Tag$3608#1"]& ]}, {}}, 
   StyleBox[{InsetBox["\<\"Prometheus\"\>", {270.4, 138800}], 
     InsetBox["\<\"F ring\"\>", {43.4, 140500}], 
     InsetBox["\<\"Pandora\"\>", {89.9, 142000}]},
    FontFamily->"Times",
    FontSize->14]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 138500},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"True Longitude (deg.)\"", TraditionalForm], 
    FormBox["\"Orbital Radius (km)\"", TraditionalForm]},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{139000, 
       FormBox["139000", TraditionalForm]}, {140000, 
       FormBox["140000", TraditionalForm]}, {141000, 
       FormBox["141000", TraditionalForm]}, {142000, 
       FormBox["142000", TraditionalForm]}}, None}, {{{0, 
       FormBox["0", TraditionalForm]}, {90, 
       FormBox["90", TraditionalForm]}, {180, 
       FormBox["180", TraditionalForm]}, {270, 
       FormBox["270", TraditionalForm]}, {360, 
       FormBox["360", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 360}, {138500, 142500}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.890555865699201*^9, 3.890555896169959*^9, {3.8905559506627274`*^9, 
   3.890555966771504*^9}, 3.8905560228899*^9, 3.890556064674822*^9, 
   3.890556124559429*^9, {3.890556384550308*^9, 3.8905564539573593`*^9}, 
   3.890556555681491*^9, 3.891103400155596*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"6f942a6a-2726-466a-a13f-81e367519c20"]
}, Open  ]]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{1053, 657},
WindowMargins->{{38, Automatic}, {Automatic, 14}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"32fd026e-8f2e-4ad8-bfc3-7eeb4c67fadc"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 489, 10, 53, "Text",ExpressionUUID->"23bb004a-cbec-4894-b6f4-79dfe3294b96"],
Cell[1050, 32, 112, 0, 67, "Section",ExpressionUUID->"3954cc47-6696-4078-8182-a1c29c90f4bd"],
Cell[1165, 34, 440, 9, 49, "Text",ExpressionUUID->"dd20e2c4-958f-4931-aaad-2f922072e35b"],
Cell[1608, 45, 416, 8, 53, "Text",ExpressionUUID->"f8a5ece4-cb8a-4b1e-bec9-25012ff9a2b4"],
Cell[2027, 55, 311, 6, 52, "Input",ExpressionUUID->"05afe8f3-5d15-4e65-9ce4-17a821c0fbc7"],
Cell[CellGroupData[{
Cell[2363, 65, 220, 3, 30, "Input",ExpressionUUID->"864c3523-6e9c-4139-a1aa-85858c5d08ea"],
Cell[2586, 70, 761, 17, 42, "Output",ExpressionUUID->"b6217b77-0d2f-4925-b3f1-7527ec2fe562"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3384, 92, 218, 3, 30, "Input",ExpressionUUID->"d24c1078-48c1-4eb0-a77f-5c75ac2cd852"],
Cell[3605, 97, 765, 17, 42, "Output",ExpressionUUID->"ae0743cd-3a4a-4ea1-a2ab-c358fcdc8cb9"]
}, Open  ]],
Cell[4385, 117, 508, 10, 53, "Text",ExpressionUUID->"37a11101-4ad2-4b4e-b133-8299aa28124c"],
Cell[4896, 129, 709, 17, 178, "Input",ExpressionUUID->"f29d89dc-9792-4350-a598-94d873abf3c7"],
Cell[5608, 148, 479, 10, 53, "Text",ExpressionUUID->"786090b6-295b-4f50-a205-983c3f6ddbf9"],
Cell[6090, 160, 496, 13, 94, "Input",ExpressionUUID->"83f8ae4a-264a-43af-8aeb-15f111cc5e1d"],
Cell[6589, 175, 602, 12, 53, "Text",ExpressionUUID->"8da042bb-6b88-4793-9ea7-446c51ef1dd3"],
Cell[7194, 189, 514, 14, 30, "Input",ExpressionUUID->"5060e3ae-eb66-4e4b-bcc1-d8463b969427"],
Cell[7711, 205, 696, 14, 53, "Text",ExpressionUUID->"3e74cc54-6392-47e7-b818-5d4430838802"],
Cell[8410, 221, 1603, 41, 73, "Input",ExpressionUUID->"a8b6bf6b-95ec-4b7e-be10-934a4f04bf35"],
Cell[10016, 264, 475, 7, 53, "Text",ExpressionUUID->"57f9736f-4ca3-4ae4-a702-9f8509486bef"],
Cell[10494, 273, 541, 13, 56, "Input",ExpressionUUID->"1ae8a2c8-6210-4ba7-afe2-e0ed557c9bd4"],
Cell[11038, 288, 493, 8, 53, "Text",ExpressionUUID->"dff6ebb5-383b-4adf-afda-b84f23db2a90"],
Cell[11534, 298, 1150, 27, 94, "Input",ExpressionUUID->"de7daba8-d569-4228-8e06-97d82d5a0442"],
Cell[12687, 327, 846, 16, 76, "Text",ExpressionUUID->"06a75a5d-185b-4ec8-86cc-f78b7e5ae589"],
Cell[13536, 345, 3410, 79, 199, "Input",ExpressionUUID->"b1b01bc4-ec06-499d-ab8c-fea4d077048b"],
Cell[16949, 426, 856, 15, 53, "Text",ExpressionUUID->"f742d7b3-aa23-4027-a625-268211c3b35f"],
Cell[CellGroupData[{
Cell[17830, 445, 266, 5, 30, "Input",ExpressionUUID->"3be279e8-b700-475f-9f43-87958befc139"],
Cell[18099, 452, 26442, 459, 251, "Output",ExpressionUUID->"6f942a6a-2726-466a-a13f-81e367519c20"]
}, Open  ]]
}
]
*)

